@@ -3,12 +3,13 @@ use warnings;
 
 package Badge::Depot;
 
-our $VERSION = '0.0103'; # VERSION
 # ABSTRACT: A framework for badges
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.0104';
 
 use Moose::Role;
 use Types::URI qw/Uri/;
-use Types::Standard qw/Str/;
+use Types::Standard qw/Str InstanceOf/;
 use MooseX::AttributeShortcuts;
 use namespace::autoclean;
 
@@ -32,6 +33,12 @@ has link_url => (
     coerce => 1,
     predicate => 1,
 );
+has zilla => (
+    is => 'ro',
+    isa => InstanceOf['Dist::Zilla'],
+    predicate => 1,
+);
+
 
 around qw/to_html to_markdown/ => sub {
     my $next = shift;
@@ -76,9 +83,23 @@ __END__
 
 Badge::Depot - A framework for badges
 
+
+
+=begin html
+
+<p>
+<img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
+<a href="https://travis-ci.org/Csson/p5-Badge-Depot"><img src="https://api.travis-ci.org/Csson/p5-Badge-Depot.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Badge-Depot-0.0104"><img src="https://badgedepot.code301.com/badge/kwalitee/Badge-Depot/0.0104" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Badge-Depot%200.0104"><img src="https://badgedepot.code301.com/badge/cpantesters/Badge-Depot/0.0104" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-100.0%-brightgreen.svg" alt="coverage 100.0%" />
+</p>
+
+=end html
+
 =head1 VERSION
 
-Version 0.0103, released 2015-03-19.
+Version 0.0104, released 2016-02-19.
 
 =head1 SYNOPSIS
 
@@ -143,6 +164,10 @@ Optional (but recommended). L<Uri|Types::URI>.
 
 The url to link the badge to. The href attribute for the a tag when rendered to html. No link is created if this isn't set.
 
+=head2 zilla
+
+This is not a user setable attribute, but rather can be used by plugins that might need to look at distribution meta data. This is only usable when using L<Pod::Weaver::Section::Badges> together with L<Dist::Zilla>.
+
 =head1 METHODS
 
 These methods are used when rendering the badge, and are not useful inside badge classes.
@@ -187,7 +212,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
